Module rdma

Module rdma 

This module contains the implementation of the rdma cgroup subsystem.

See the Kernel’s documentation for more information about this subsystem, found at: Documentation/cgroup-v1/rdma.txt

Structs

RdmaController
A controller that allows controlling the rdma subsystem of a Cgroup.