Struct cgroups::CpuResources[][src]

pub struct CpuResources {
    pub update_values: bool,
    pub cpus: String,
    pub mems: String,
    pub shares: u64,
    pub quota: i64,
    pub period: u64,
    pub realtime_runtime: i64,
    pub realtime_period: u64,
}

Resources limits about how the tasks can use the CPU.

Fields

Whether values should be applied to the controller.

A comma-separated list of CPU IDs where the task in the control group can run. Dashes between numbers indicate ranges.

Same syntax as the cpus field of this structure, but applies to memory nodes instead of processors.

Weight of how much of the total CPU time should this control group get. Note that this is hierarchical, so this is weighted against the siblings of this control group.

In one period, how much can the tasks run in nanoseconds.

Period of time in nanoseconds.

This is currently a no-operation.

This is currently a no-operation.