Struct cgroups::HugePageResources [−][src]
pub struct HugePageResources {
pub update_values: bool,
pub limits: Vec<HugePageResource>,
}Provides the ability to set consumption limit on each type of hugepages.
Fields
update_values: bool
Whether values should be applied to the controller.
limits: Vec<HugePageResource>
Set a limit of consumption for each hugepages type.