Struct cgroups::PidResources[][src]

pub struct PidResources {
    pub update_values: bool,
    pub maximum_number_of_processes: PidMax,
}

Resources limits on the number of processes.

Fields

Whether values should be applied to the controller.

The maximum number of processes that can exist in the control group.

Note that attaching processes to the control group will still succeed even if the limit would be violated, however forks/clones inside the control group will have with EAGAIN if they would violate the limit set here.