Struct cgroups::PidResources [−][src]
Resources limits on the number of processes.
Fields
update_values: bool
Whether values should be applied to the controller.
maximum_number_of_processes: PidMax
The maximum number of processes that can exist in the control group.
Note that attaching processes to the control group will still succeed even if the limit
would be violated, however forks/clones inside the control group will have with EAGAIN if
they would violate the limit set here.